@@ -7,17 +7,19 @@ use parent qw(Exporter);
 
 use Term::ANSIColor qw(colored);
 
-our $VERSION = '0.17'; # Don't forget to change in pod below
+our $VERSION = '0.18'; # Don't forget to change in pod below
 
 our @EXPORT = qw(
     die_fatal
     die_info
+    die_alert
     die_notice
 
     log_fd
 
     log_fatal
     log_error
+    log_alert
     log_notice
     log_warn
     log_info
@@ -28,12 +30,14 @@ our @EXPORT = qw(
 our $COLORS = {
     FATAL  => 'bold red',
     ERROR  => 'red',
-    NOTICE => 'bold white',
+    ALERT  => 'bold yellow',
     WARN   => 'yellow',
     INFO   => 'cyan',
     DEBUG  => 'blue',
     TRACE  => 'magenta'
 };
+$COLORS->{NOTICE} = $COLORS->{ALERT}; # Deprecated
+
 our $LEVEL = 0;
 our $POSITIONS = undef;
 my $FD = \*STDERR;       # descriptor
@@ -52,23 +56,25 @@ sub _die($$$$) {
 
 sub _pfx($) {
     my ($S, $M, $H, $d, $m, $y) = localtime(time);
-    my $pfx = sprintf "[%04i-%02i-%02i %02i:%02i:%02i %i %6s] ",
+    my $pfx = sprintf "[%04i-%02i-%02i %02i:%02i:%02i %i %5s] ",
         $y + 1900, $m + 1, $d, $H, $M, $S, $$, $_[0];
     return ($COLOR ? colored($pfx, $COLORS->{$_[0]}) : $pfx) .
         (($POSITIONS or $LEVEL > 4) ? join(":", (caller(1))[1,2]) . " " : "");
 }
 
-sub die_fatal(;$;$)  { _die $_[1] || 127, $LEVEL > -2, _pfx('FATAL'),  $_[0] }
-sub die_notice(;$;$) { _die $_[1] || 0,   $LEVEL > -1, _pfx('NOTICE'), $_[0] }
-sub die_info(;$;$)   { _die $_[1] || 0,   $LEVEL >  1, _pfx('INFO'),   $_[0] }
+sub die_fatal(;$;$) { _die $_[1] || 127, $LEVEL > -2, _pfx('FATAL'), $_[0] }
+sub die_alert(;$;$) { _die $_[1] || 0,   $LEVEL > -1, _pfx('ALERT'), $_[0] }
+*die_notice = \&die_alert; # Deprecated
+sub die_info(;$;$)  { _die $_[1] || 0,   $LEVEL >  1, _pfx('INFO'),  $_[0] }
 
-sub log_fatal(&)  { print $FD _pfx('FATAL')  . $_[0]->($_) . "\n" if $LEVEL > -2 }
-sub log_error(&)  { print $FD _pfx('ERROR')  . $_[0]->($_) . "\n" if $LEVEL > -1 }
-sub log_notice(&) { print $FD _pfx('NOTICE') . $_[0]->($_) . "\n" if $LEVEL > -1 }
-sub log_warn(&)   { print $FD _pfx('WARN')   . $_[0]->($_) . "\n" if $LEVEL >  0 }
-sub log_info(&)   { print $FD _pfx('INFO')   . $_[0]->($_) . "\n" if $LEVEL >  1 }
-sub log_debug(&)  { print $FD _pfx('DEBUG')  . $_[0]->($_) . "\n" if $LEVEL >  2 }
-sub log_trace(&)  { print $FD _pfx('TRACE')  . $_[0]->($_) . "\n" if $LEVEL >  3 }
+sub log_fatal(&) { print $FD _pfx('FATAL') . $_[0]->($_) . "\n" if $LEVEL > -2 }
+sub log_error(&) { print $FD _pfx('ERROR') . $_[0]->($_) . "\n" if $LEVEL > -1 }
+sub log_alert(&) { print $FD _pfx('ALERT') . $_[0]->($_) . "\n" if $LEVEL > -1 }
+*log_notice = \&log_alert; # Deprecated
+sub log_warn(&)  { print $FD _pfx('WARN')  . $_[0]->($_) . "\n" if $LEVEL >  0 }
+sub log_info(&)  { print $FD _pfx('INFO')  . $_[0]->($_) . "\n" if $LEVEL >  1 }
+sub log_debug(&) { print $FD _pfx('DEBUG') . $_[0]->($_) . "\n" if $LEVEL >  2 }
+sub log_trace(&) { print $FD _pfx('TRACE') . $_[0]->($_) . "\n" if $LEVEL >  3 }
 
 sub log_fd(;$) {
     if (@_) {
@@ -88,11 +94,11 @@ Log::Log4Cli -- Lightweight logger for command line tools
 
 =head1 VERSION
 
-Version 0.17
+Version 0.18
 
 =head1 SYNOPSIS
 
-    Log::Log4Cli;
+    use Log::Log4Cli;
 
     $Log::Log4Cli::COLORS->{DEBUG} = 'green'; # redefine color (Term::ANSIColor notation)
     $Log::Log4Cli::LEVEL = 4;                 # set loglevel
@@ -105,18 +111,17 @@ Version 0.17
     $Log::Log4Cli::COLOR = 0;                 # now colors disabled
 
     my $guts = { some => "value" };
-    log_trace {                               # block will be called only when TRACE level enabled
+    log_trace {                               # block executed when appropriate level enabled only
         require Data::Dumper;
         return "Guts:\n" . Data::Dumper->Dump([$guts]);
     };
 
-    die_info 'All done', 0                    # args optional
+    die_info 'All done', 0;
 
 =head1 DESCRIPTION
 
-The goal for this module is to provide suffucient (but user friendly) logging facilities
-for command line tools with minimal impact on performance, minimal configuration and
-without non-core dependencies.
+Lightweight, but sufficient and user friendly logging for command line tools with
+minimal impact on performance, no configuration and no non-core dependencies.
 
 =head1 EXPORT
 
@@ -124,19 +129,21 @@ All subroutines described below are exported by default.
 
 =head1 SUBROUTINES
 
-=head2 die_fatal, die_info, die_notice
+=head2 die_fatal, die_alert, die_notice, die_info
 
     die_fatal "Something terrible happened", 8;
 
-Log message and die with provided exid code. All arguments are optional. If second arg (exit code) omitted
-die_info, die_notice and die_fatal will use 0, 0 and 127 respectively.
+Log message and exit with provided code. All arguments are optional. If second arg
+(exit code) omitted die_fatal, die_alert and die_info will exit with 127, 0 and 0
+respectively. C<die_notice> is deprecated and will be removed in future releases.
 
-=head2 log_fatal, log_error, log_notice, log_warn, log_info, log_debug, log_trace
+=head2 log_fatal, log_error, log_alert, log_notice, log_warn, log_info, log_debug, log_trace
 
     log_error { "Something went wrong!" };
 
-Execute passed code block and write it's return value if loglevel permit so. Set C<$Log::Log4Cli::COLOR> to false value
-if you want to disable colors.
+Execute passed code block and write it's return value if loglevel permit so. Set
+C<$Log::Log4Cli::COLOR> to false value to disable colors. C<log_notice> is
+deprecated and will be removed in future releases.
 
 =head2 log_fd
 
@@ -144,18 +151,17 @@ Get/set file descriptor for log messages. C<STDERR> is used by default.
 
 =head1 LOG LEVELS
 
-Only builtin loglevels supported. Here they are:
+Only builtin loglevels supported:
 
-    # LEVEL     VALUE   COLOR
     FATAL       -1      'bold red',
     ERROR        0      'red',
-    NOTICE       0      'bold white',
+    ALERT        0      'bold yellow',
     WARN         1      'yellow',
     INFO         2      'cyan',
     DEBUG        3      'blue',
     TRACE        4      'magenta'
 
-Colors may be changed, see L</SYNOPSIS>.
+Colors may be changed, see L</SYNOPSIS>. Default loglevel is C<ERROR> (0).
 
 =head1 SEE ALSO
 
